==> haskell-mockery-0.3.5-772-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-IGCi7TJwTqKGjHcDygrXD1
key:                  mockery-0.3.5-IGCi7TJwTqKGjHcDygrXD1
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  3996231f36e8424a08f9f62221eb5727
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-IGCi7TJwTqKGjHcDygrXD1
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-CBCTeUV4ZHs324ItA0qGle
    temporary-1.3-836zY2cPz8HAaBXH2WMEd1

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-776-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-CNb7yfDv0HuLMn2MOkdc9K
key:                  mockery-0.3.5-CNb7yfDv0HuLMn2MOkdc9K
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  d7b3078442c1f7c3534b4b232023e041
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-CNb7yfDv0HuLMn2MOkdc9K
depends:
    base-4.17.2.1 base-compat-0.13.0-4bY7VGgUDQwFnN0OMsXbDp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-Irslz3rABHG3EleM31W5Xr
    temporary-1.3-3mtZbkJPoBb5nlmfkfYt6T

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
